@@ -4,11 +4,9 @@
 #'
 #' @name gghighlight-package
 #' @import rlang
-#' @importFrom ggplot2 %+%
 #' @importFrom ggplot2 ggplot_add
 #' @importFrom dplyr desc across if_all all_of
-#' @docType package
-NULL
+"_PACKAGE"
 
 #' @importFrom ggplot2 aes
 #' @export
@@ -21,3 +19,12 @@ utils::globalVariables("where")
 #' @importFrom dplyr n
 #' @export
 dplyr::n
+
+# TODO: remove this and replace all %+% with + when I remove support for ggplot2 v3
+`%+%` <- function(e1, e2) {
+  if (utils::packageVersion("ggplot2") > "3.5.2.9000") {
+    e1 + e2
+  } else {
+    ggplot2::`%+%`(e1, e2)
+  }
+}
