@@ -79,7 +79,7 @@ ggplot(d2, aes(idx, value)) +
   gghighlight(value > 0, label_key = type)
 
 ## ----predicate-example, eval=FALSE--------------------------------------------
-#  max(value) > 20
+# max(value) > 20
 
 ## ----numeric-highlight--------------------------------------------------------
 ggplot(d, aes(idx, value, colour = type)) +
@@ -94,7 +94,7 @@ ggplot(d) +
 ## ----labels2------------------------------------------------------------------
 ggplot(d) +
   geom_line(aes(idx, value, colour = type)) +
-  gghighlight(max(value) > 20, label_params = list(linewidth = 10))
+  gghighlight(max(value) > 20, label_params = list(size = 10))
 
 ## ----labels3------------------------------------------------------------------
 p <- ggplot(d2, aes(idx, value)) +
