@@ -1,5 +1,6 @@
 grey07 <- "#BEBEBEB2"
 
+# fmt: skip
 d <- tibble::tribble(
   ~x, ~y, ~type, ~value,
    1,  2,   "a",      0,
@@ -20,6 +21,7 @@ d_bleached$ids <- factor(ids)
 prefix <- expr_text(VERY_SECRET_COLUMN_NAME)
 names(d_bleached) <- paste0(prefix, c(1:3, "group"))
 
+# fmt: skip
 aes_bleached <- aes(
   x      = !!sym(paste0(prefix, "1")),
   y      = !!sym(paste0(prefix, "2")),
@@ -31,7 +33,6 @@ aes_bleached <- aes(
 
 # tests -------------------------------------------------------------------
 
-
 test_that("gghighlight() does not change the existing layers", {
   p1 <- ggplot(d, aes(x, y, colour = type)) + geom_line()
   p2 <- ggplot(d, aes(x, y, colour = type)) + geom_line()
@@ -43,6 +44,25 @@ test_that("gghighlight() does not change the existing layers", {
   expect_equal(as.list(p1$layers[[1]]), as.list(p2$layers[[1]]))
 })
 
+test_that("gghighlight() renames layer name on ggplot2", {
+  skip_if_not(
+    utils::packageVersion("ggplot2") > "3.5.2.9000",
+  )
+
+  p <- ggplot(d, aes(x, y, colour = type)) +
+    geom_line(name = "foo") +
+    gghighlight()
+
+  expect_equal(
+    names(p$layers),
+    c(
+      "foo", # First layer uses the same name
+      "foo__sieved", # Additional layer has a suffix to avoid duplicated name
+      "geom" # Layers for label uses the default name.
+    )
+  )
+})
+
 test_that("gghighlight() works with the plot with one layer, grouped", {
   d_sieved <- d[d$type != "a", ]
 
@@ -77,15 +97,25 @@ test_that("gghighlight() works with the plot with one layer, grouped", {
     dplyr::slice(1) %>%
     dplyr::ungroup()
 
-  l_label <- ggrepel::geom_label_repel(aes(x, y, colour = type, label = type), d_label, fill = "white")
+  l_label <- ggrepel::geom_label_repel(
+    aes(x, y, colour = type, label = type),
+    d_label,
+    fill = "white"
+  )
   for (p in list(p1, p2, p3)) {
     p_highlighted <- p + gghighlight(mean(value) > 1, use_direct_label = TRUE)
     expect_equal(p_highlighted$data, d_sieved)
-    expect_equal_layers(p_highlighted$layers, list(l_bleached, l_sieved, l_label))
+    expect_equal_layers(
+      p_highlighted$layers,
+      list(l_bleached, l_sieved, l_label)
+    )
     if (utils::packageVersion("ggplot2") < "3.5.0") {
       expect_equal(p_highlighted$guides, list(colour = "none", fill = "none"))
     } else {
-      expect_equal(p_highlighted$guides$guides, list(colour = "none", fill = "none"))
+      expect_equal(
+        p_highlighted$guides$guides,
+        list(colour = "none", fill = "none")
+      )
     }
   }
 })
@@ -93,7 +123,8 @@ test_that("gghighlight() works with the plot with one layer, grouped", {
 test_that("gghighlight() works with the plot without layers, grouped", {
   d_sieved <- d[d$type != "a", ]
 
-  p <- ggplot(d, aes(x, y, colour = type)) + gghighlight(mean(value) > 1, use_direct_label = FALSE)
+  p <- ggplot(d, aes(x, y, colour = type)) +
+    gghighlight(mean(value) > 1, use_direct_label = FALSE)
   expect_equal(p$data, d_sieved)
 })
 
@@ -105,30 +136,37 @@ test_that("gghighlight() works with the plot with one layer, ungrouped", {
   p1 <- ggplot(d, aes(x, y, colour = type)) +
     geom_point()
 
-  expect_equal_layers((p1 + gghighlight(value > 1, use_group_by = FALSE, use_direct_label = FALSE))$layers,
-                      list(l_bleached, l_sieved))
+  expect_equal_layers(
+    (p1 +
+      gghighlight(
+        value > 1,
+        use_group_by = FALSE,
+        use_direct_label = FALSE
+      ))$layers,
+    list(l_bleached, l_sieved)
+  )
 })
 
 test_that("gghighlight() works with the plot without layers, grouped", {
   d_sieved <- d[d$value > 1, ]
 
-  p <- ggplot(d, aes(x, y, colour = type)) + gghighlight(value > 1, use_group_by = FALSE, use_direct_label = FALSE)
+  p <- ggplot(d, aes(x, y, colour = type)) +
+    gghighlight(value > 1, use_group_by = FALSE, use_direct_label = FALSE)
   expect_equal(p$data, d_sieved)
 })
 
 
-
 d_bleached <- d[1:3]
 d_bleached$ids <- factor(ids)
 prefix <- expr_text(VERY_SECRET_COLUMN_NAME)
 names(d_bleached) <- paste0(prefix, c(1:3, "group"))
 
 aes_bleached <- aes(
-  x      = !!sym(paste0(prefix, "1")),
-  y      = !!sym(paste0(prefix, "2")),
+  x = !!sym(paste0(prefix, "1")),
+  y = !!sym(paste0(prefix, "2")),
   colour = !!sym(paste0(prefix, "3")),
-  fill   = NULL,
-  group  = !!sym(paste0(prefix, "group"))
+  fill = NULL,
+  group = !!sym(paste0(prefix, "group"))
 )
 
 test_that("gghighlight() works with two layers, grouped", {
@@ -141,28 +179,45 @@ test_that("gghighlight() works with two layers, grouped", {
 
   l_bleached_1 <- geom_line(aes_bleached, d_bleached, colour = grey07)
   l_sieved_1 <- geom_line(aes(x, y, colour = type), d_sieved)
-  l_bleached_2 <- geom_point(aes_bleached2, d_bleached2,
-                             shape = "circle filled", colour = grey07, fill = grey07)
-  l_sieved_2 <- geom_point(aes(x, y, colour = type, fill = type), d_sieved,
-                           shape = "circle filled")
+  l_bleached_2 <- geom_point(
+    aes_bleached2,
+    d_bleached2,
+    shape = "circle filled",
+    colour = grey07,
+    fill = NA
+  )
+  l_sieved_2 <- geom_point(
+    aes(x, y, colour = type, fill = type),
+    d_sieved,
+    shape = "circle filled"
+  )
 
   p1 <- ggplot(d, aes(x, y, colour = type, fill = type)) +
     geom_line() +
     geom_point(shape = "circle filled")
 
-  expect_equal_layers((p1 + gghighlight(mean(value) > 1, use_direct_label = FALSE))$layers,
-                      list(l_bleached_1, l_bleached_2, l_sieved_1, l_sieved_2))
+  expect_equal_layers(
+    (p1 + gghighlight(mean(value) > 1, use_direct_label = FALSE))$layers,
+    list(l_bleached_1, l_bleached_2, l_sieved_1, l_sieved_2)
+  )
 
   # If n = 1, only one layer above is highlighted.
-  expect_equal_layers((p1 + gghighlight(mean(value) > 1, n = 1, use_direct_label = FALSE))$layers,
-                      list(geom_line(data = d, aes(x, y, colour = type)),
-                           l_bleached_2, l_sieved_2))
+  expect_equal_layers(
+    (p1 + gghighlight(mean(value) > 1, n = 1, use_direct_label = FALSE))$layers,
+    list(
+      geom_line(data = d, aes(x, y, colour = type)),
+      l_bleached_2,
+      l_sieved_2
+    )
+  )
 
   # if the data is grouped, the result is the same
   p1$data <- dplyr::group_by(d, .data$type)
 
-  expect_equal_layers((p1 + gghighlight(mean(value) > 1, use_direct_label = FALSE))$layers,
-                      list(l_bleached_1, l_bleached_2, l_sieved_1, l_sieved_2))
+  expect_equal_layers(
+    (p1 + gghighlight(mean(value) > 1, use_direct_label = FALSE))$layers,
+    list(l_bleached_1, l_bleached_2, l_sieved_1, l_sieved_2)
+  )
 
   # If n is larger than the number of layers, it throws error.
   expect_error(p1 + gghighlight(mean(value) > 1, n = 3))
@@ -171,24 +226,62 @@ test_that("gghighlight() works with two layers, grouped", {
 test_that("gghighlight() works with two layers, ungrouped", {
   d_sieved <- d[d$value > 1, ]
 
-  l_bleached_1 <- geom_point(aes_bleached, d_bleached, shape = "circle open", size = 5,
-                             colour = grey07, fill = NA)
-  l_sieved_1 <- geom_point(aes(x, y, colour = type), d_sieved, shape = "circle open", size = 5)
-  l_bleached_2 <- geom_point(aes_bleached, d_bleached,
-                             colour = grey07, fill = NA)
+  l_bleached_1 <- geom_point(
+    aes_bleached,
+    d_bleached,
+    shape = "circle open",
+    size = 5,
+    colour = grey07,
+    fill = NA
+  )
+  l_sieved_1 <- geom_point(
+    aes(x, y, colour = type),
+    d_sieved,
+    shape = "circle open",
+    size = 5
+  )
+  l_bleached_2 <- geom_point(
+    aes_bleached,
+    d_bleached,
+    colour = grey07,
+    fill = NA
+  )
   l_sieved_2 <- geom_point(aes(x, y, colour = type), d_sieved)
 
   p1 <- ggplot(d, aes(x, y, colour = type)) +
     geom_point(shape = "circle open", size = 5) +
     geom_point()
 
-  expect_equal_layers((p1 + gghighlight(value > 1, use_group_by = FALSE, use_direct_label = FALSE))$layers,
-                      list(l_bleached_1, l_bleached_2, l_sieved_1, l_sieved_2))
+  expect_equal_layers(
+    (p1 +
+      gghighlight(
+        value > 1,
+        use_group_by = FALSE,
+        use_direct_label = FALSE
+      ))$layers,
+    list(l_bleached_1, l_bleached_2, l_sieved_1, l_sieved_2)
+  )
 
   # If n = 1, only one layer above is highlighted.
-  expect_equal_layers((p1 + gghighlight(value > 1, n = 1, use_group_by = FALSE, use_direct_label = FALSE))$layers,
-                      list(geom_point(data = d, aes(x, y, colour = type), shape = "circle open", size = 5),
-                           l_bleached_2, l_sieved_2))
+  expect_equal_layers(
+    (p1 +
+      gghighlight(
+        value > 1,
+        n = 1,
+        use_group_by = FALSE,
+        use_direct_label = FALSE
+      ))$layers,
+    list(
+      geom_point(
+        data = d,
+        aes(x, y, colour = type),
+        shape = "circle open",
+        size = 5
+      ),
+      l_bleached_2,
+      l_sieved_2
+    )
+  )
 
   # If n is larger than the number of layers, it throws error.
   expect_error(p1 + gghighlight(mean(value) > 1, n = 3))
@@ -204,19 +297,27 @@ test_that("gghighlight() works with annotations", {
     l_annotate
 
   # ignore annotation
-  expect_warning(p1 <- p + gghighlight(value > 1, use_group_by = FALSE, use_direct_label = FALSE))
-  expect_equal_layers(p1$layers,
-                      list(l_bleached, l_annotate, l_sieved))
+  expect_warning(
+    p1 <- p +
+      gghighlight(value > 1, use_group_by = FALSE, use_direct_label = FALSE)
+  )
+  expect_equal_layers(p1$layers, list(l_bleached, l_annotate, l_sieved))
 
   # raise error
   expect_error(
     suppressWarnings(
-      p + gghighlight(no_such_column > 1, use_group_by = FALSE, use_direct_label = FALSE)
+      p +
+        gghighlight(
+          no_such_column > 1,
+          use_group_by = FALSE,
+          use_direct_label = FALSE
+        )
     )
   )
 })
 
 test_that("gghighlight() works with facets", {
+  # fmt: skip
   d <- tibble::tribble(
     ~idx, ~value, ~cat1, ~cat2,
        1,     10,   "a", "1-2",
@@ -239,6 +340,7 @@ test_that("gghighlight() works with facets", {
   names(d_bleached) <- paste0(prefix, c(1:3, "group"))
   d_bleached <- dplyr::bind_cols(d_bleached, d)
 
+  # fmt: skip
   aes_bleached <- aes(
     x      = !!sym(paste0(prefix, "1")),
     y      = !!sym(paste0(prefix, "2")),
@@ -254,7 +356,12 @@ test_that("gghighlight() works with facets", {
   p1 <- ggplot(d, aes(idx, value, colour = cat1)) +
     geom_point() +
     facet_wrap(vars(cat2)) +
-    gghighlight(max(value) > 10, use_group_by = TRUE, use_direct_label = FALSE, calculate_per_facet = TRUE)
+    gghighlight(
+      max(value) > 10,
+      use_group_by = TRUE,
+      use_direct_label = FALSE,
+      calculate_per_facet = TRUE
+    )
 
   expect_equal_layers(p1$layers, list(l_bleached, l_sieved))
 
@@ -262,7 +369,12 @@ test_that("gghighlight() works with facets", {
   p2 <- ggplot(d, aes(idx, value, colour = cat1)) +
     geom_point() +
     facet_wrap(vars(cat2)) +
-    gghighlight(value > 10, use_group_by = FALSE, use_direct_label = FALSE, calculate_per_facet = TRUE)
+    gghighlight(
+      value > 10,
+      use_group_by = FALSE,
+      use_direct_label = FALSE,
+      calculate_per_facet = TRUE
+    )
 
   l_sieved2 <- geom_point(aes(idx, value, colour = cat1), d[d$value > 10, ])
   expect_equal_layers(p2$layers, list(l_bleached, l_sieved2))
