@@ -1,6 +1,11 @@
 test_that("gghighlight() highlights correctly", {
   testthat::skip_if_not_installed("vdiffr")
 
+  # no visual difference, but the SVG texts are incompatible after v4
+  skip_if_not(
+    utils::packageVersion("ggplot2") > "3.5.2.9000",
+  )
+
   vdiffr::expect_doppelganger(
     "simple bar chart",
     ggplot(mpg, aes(class, fill = factor(cyl))) +
@@ -24,12 +29,16 @@ test_that("gghighlight() highlights correctly", {
   )
 
   set.seed(99)
-  value <- unlist(lapply(c(1, 10, 20), function(x) cumsum(runif(100, min = -x, max = x))))
-  d_line <- data.frame(index = rep(1:100, times = 3),
-                       value = value,
-                       value01 = value / rep(c(1, 10, 20), each = 100),
-                       group = rep(c("a", "b", "c"), each = 100),
-                       stringsAsFactors = FALSE)
+  value <- unlist(lapply(c(1, 10, 20), function(x) {
+    cumsum(runif(100, min = -x, max = x))
+  }))
+  d_line <- data.frame(
+    index = rep(1:100, times = 3),
+    value = value,
+    value01 = value / rep(c(1, 10, 20), each = 100),
+    group = rep(c("a", "b", "c"), each = 100),
+    stringsAsFactors = FALSE
+  )
 
   vdiffr::expect_doppelganger(
     "simple line chart",
